bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainDistribution.__init__
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: GaussianMarkovChainDistribution.__init__